@@ -12,6 +12,7 @@ from matorage.utils import is_torch_available, is_tf_available
 def suite():
     test_modules = [
         "tests.test_datasaver",
+        "tests.test_nas",
     ]
     if is_torch_available():
         test_modules.extend([
@@ -36,13 +37,5 @@ def suite():
         alltests.addTest(test_suite())
     return alltests
 
-
-def test(verbose=False):
-    result = unittest.TextTestRunner(verbosity=1 + int(verbose)).run(suite())
-    if result.wasSuccessful():
-        return 0
-    else:
-        return 1
-
 if __name__ == '__main__':
-    test()
+    unittest.main(defaultTest="suite", warnings=False)
